@@ -1,15 +1,17 @@
+import os
 import sys
 from .type_checker import is_int
 
 __all__ = ['get_env']
 
 
-def get_env(const_name, path=".env"):
+def get_env(const_name, file_path=".env"):
     try:
-        with open(path, 'r') as env_file:
+        file_path = os.path.abspath(os.path.expanduser(os.path.expandvars(file_path)))
+        with open(file_path, 'r') as env_file:
             env_file_lines = env_file.readlines()
     except FileNotFoundError:
-        print(f"dotenv: The {path} not found.")
+        print(f"dotenv: The {file_path} not found.")
         sys.exit(1)
 
     env_consts = {}
@@ -26,7 +28,7 @@ def get_env(const_name, path=".env"):
     try:
         config_var = env_consts[const_name]
     except KeyError:
-        print(f"dotenv: The constant you specified is not contained in the {path}.")
+        print(f"dotenv: The constant you specified is not contained in the {file_path}.")
         sys.exit(1)
     return config_var
 
